use strict;
use warnings;
use Test::More;

# generated by Dist::Zilla::Plugin::Test::PodSpelling 2.007004
use Test::Spelling 0.12;
use Pod::Wordlist;


add_stopwords(<DATA>);
all_pod_files_spelling_ok( qw( bin lib ) );
__DATA__
ARRAYn
Aaron
Adam
Anno
AnnoCPAN
BackPan
Brad
Branno
Crane
DROLSKY
DROLSKY's
Dave
David
EXPR
Etheridge
Filmer
Forschinger
Golden
Inkster
Jens
KEYFUNC
Karen
Kennedy
LMU
List
MULTICALL
Mash
Matsuno
McCauley
Muey
PP
PRs
Parseval
PayPal
Purkis
Rabbitson
Rehsack
Rezic
Ricardo
Rolsky
Rolsky's
Roode
Siegel
Signes
Slaven
SomeUtils
Summersault
TODO
Tassilo
Tatham
Thegler
Toby
Tokuhiro
Tom
Wyant
adamk
arc
autarch
bnjf
bsearchidx
dagolden
de
drolsky
ether
firstidx
firstres
firstval
glitchy
jddurand
jeandamiendurand
jrmash
lastidx
lastres
lastval
lib
listify
mail
minmax
natatime
notall
onlyidx
onlyres
onlyval
refactor
rehsack
rehsackATcpan
rjbs
sno
tassilo
thusly
tokuhirom
uniq
von
wyant
